<?php

namespace HS\Install\System\Checks;

use HS\System\Features;
use HS\Install\System\SystemCheckInterface;

class PhpVersion implements SystemCheckInterface
{
    /**
     * @var \HS\System\Features
     */
    protected $features;

    /**
     * @var bool
     */
    protected $valid;

    /**
     * Php Version Error.
     * @var string
     */
    protected $error;

    public function __construct(Features $features)
    {
        $this->features = $features;
    }

    /**
     * This is required to pass.
     * @return bool
     */
    public function required()
    {
        return true;
    }

    /**
     * If we cannot connect to the DB
     * we get an exception here.
     * @return bool
     */
    public function valid()
    {
        if (is_bool($this->valid)) {
            return $this->valid;
        }

        $this->valid = $this->features->phpBetween('7.3','8.3');

        if (! $this->valid) {
            $this->error = 'PHP version detected: '.PHP_VERSION.'. For more information visit: https://support.helpspot.com/index.php?pg=kb.page&id=660';
        }

        return $this->valid;
    }

    /**
     * @return mixed
     */
    public function getError()
    {
        return $this->error;
    }
}
