<?php

namespace HS\Notifications;

use HS\Mailbox;
use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use HS\Notifications\DatabaseNotification;
use Illuminate\Support\Facades\DB;
use HS\User;

class MailboxCheckError extends Notification
{
    use Queueable;

    /**
     * @var mailbox
     */
    private $mailbox;

    /**
     * @var error
     */
    private $error;

    /**
     * Create a new notification instance.
     *
     * @param Mailbox $Mailbox
     * @param String $error
     */
    public function __construct(Mailbox $mailbox, String $error)
    {
        $this->mailbox = $mailbox;
        $this->error = $error;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['database'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
                    ->line('The introduction to the notification.')
                    ->action('Notification Action', url('/'))
                    ->line('Thank you for using our application!');
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */

     public function toArray($notifiable)
     {
         $data = [
             'style' => 'error',
             'route' => route('admin', ['pg' => 'admin.mailboxes.crud', 'resourceid' => $this->mailbox->xMailbox]),
             'mailbox' => $this->mailbox->xMailbox,
             'error' => $this->error,
         ];
         // prevent duplicate notifications
         $existingNotification = DatabaseNotification::where('type', self::class)
             ->where('notifiable_id', $notifiable->xPerson)
             ->where('data->mailbox', $this->mailbox->xMailbox)
             ->where('read_at', null)
             ->first();
         
        if ($existingNotification) {
            return;
        }
     
         return $data;
     }

    public static function sendUniqueMailboxCheckError($mailbox, $error)
    {
        $users = User::where('fUserType',1)->where('fDeleted',0)->get();
        
        foreach ($users as $user) {
            $existingNotification = DatabaseNotification::where('type', self::class)
                ->where('notifiable_id', $user->xPerson)
                ->where('data->mailbox', $mailbox->xMailbox)
                ->where('read_at', null)
                ->first();

                //dd($existingNotification);

            if (!$existingNotification) {
                $user->notify(new MailboxCheckError($mailbox,$error));
            }
        }
    }
}
