<?php

use LDAP\Result;
use Orhanerday\OpenAi\OpenAi;

/******************************************
Get OpenAI API Key
 ******************************************/
function apiGetOpenAIKey(){
    return hs_setting('cHD_OPENAI_KEY', '');
}
/******************************************
Check OpenAI Integration is Enabled
 ******************************************/
function apiGetOpenAIEnabled(){
    $apiEnabled = $GLOBALS['DB']->GetRow('SELECT tValue FROM HS_Settings WHERE sSetting = ?', ['cHD_OPENAI_ENABLED'])['tValue'];
    if (apiGetOpenAIKey() != '' && $apiEnabled == 1) {
        return true;
    } else {
        return false;
    }
}
/******************************************
Test OpenAI Integration
 ******************************************/
function apiTestOpenAIKey($key){
    $open_ai = apiInitialzeOpenAI($key);
    $models = $open_ai->listModels();
    $models = json_decode($models);
    if ($models->error){
        return $models->error->message;
    } else {
        return "success";
    }
}

/******************************************
SET OpenAI API Key
 ******************************************/
function apiSetOpenAIEnabled($enabled)
{
    $enabledSetting = $GLOBALS['DB']->GetRow('SELECT * FROM HS_Settings WHERE sSetting = ?', ['cHD_OPENAI_ENABLED']);

    if ($enabledSetting) {
        return storeGlobalVar('cHD_OPENAI_ENABLED', $enabled);
    }

    $result = $GLOBALS['DB']->Execute('INSERT INTO HS_Settings (sSetting, tValue) VALUES (?, ?)', ['cHD_OPENAI_ENABLED', $enabled]);
    \Facades\HS\Cache\Manager::forget(\HS\Cache\Manager::CACHE_SETTINGS_KEY);

    return $result;
}

function apiSetOpenAILanguage($language)
{
    $enabledSetting = $GLOBALS['DB']->GetRow('SELECT * FROM HS_Settings WHERE sSetting = ?', ['cHD_OPENAI_LANGUAGE']);

    if ($enabledSetting) {
        return storeGlobalVar('cHD_OPENAI_LANGUAGE', $language);
    }

    $result = $GLOBALS['DB']->Execute('INSERT INTO HS_Settings (sSetting, tValue) VALUES (?, ?)', ['cHD_OPENAI_LANGUAGE', $language]);
    \Facades\HS\Cache\Manager::forget(\HS\Cache\Manager::CACHE_SETTINGS_KEY);

    return $result;
}
/******************************************
SET OpenAI API Key
 ******************************************/
function apiSetOpenAIKey($key)
{
    $apikey = $GLOBALS['DB']->GetRow('SELECT * FROM HS_Settings WHERE sSetting = ?', ['cHD_OPENAI_KEY']);
    apiSetOpenAIEnabled(1);
    if ($apikey) {
        return storeGlobalVar('cHD_OPENAI_KEY', $key);
        \Facades\HS\Cache\Manager::forget(\HS\Cache\Manager::CACHE_SETTINGS_KEY);
    }

    $result = $GLOBALS['DB']->Execute('INSERT INTO HS_Settings (sSetting, tValue) VALUES (?, ?)', ['cHD_OPENAI_KEY', $key]);
    \Facades\HS\Cache\Manager::forget(\HS\Cache\Manager::CACHE_SETTINGS_KEY);


    return $result;
}

/******************************************
Get OpenAI API Models
 ******************************************/
function apiGetOpenAIModels()
{
    $open_ai = apiInitialzeOpenAI();
    $models = $open_ai->listModels();
    $models = json_decode($models);
    if (!$models->error->message == 'Invalid authorization header'){
        $modelList=[];
        foreach($models->data as $model) {
            // add new models that are allowed
            if ($model->id == 'gpt-3.5-turbo' || $model->id == 'gpt-4' || $model->id == 'gpt-4-32k'){
            $modelList[]= $model->id;
            }
        }
    } else {
        $modelList = 'No Open Ai Connection';
    }
    return $modelList;
}

/******************************************
SET OpenAI API Model
 ******************************************/
function apiSetOpenAIModel($model)
{
    $modelSetting = $GLOBALS['DB']->GetRow('SELECT * FROM HS_Settings WHERE sSetting = ?', ['cHD_OPENAI_MODEL']);

    if ($modelSetting) {
        return storeGlobalVar('cHD_OPENAI_MODEL', $model);
    }

    $result = $GLOBALS['DB']->Execute('INSERT INTO HS_Settings (sSetting, tValue) VALUES (?, ?)', ['cHD_OPENAI_MODEL', $model]);
    \Facades\HS\Cache\Manager::forget(\HS\Cache\Manager::CACHE_SETTINGS_KEY);

    return $result;
}
/******************************************
Create a new OpenAI instance
 ******************************************/
function apiInitialzeOpenAI($key = '')
{
    $key = $key ?: hs_setting('cHD_OPENAI_KEY', '');
    return new OpenAi($key);
}

function apiGetPromptFolders()
{
    $res = DB::table('HS_Prompts')->distinct('sPromptFolder')->orderBy('sPromptFolder','ASC')->get('sPromptFolder');
    return $res->toArray();
}

function apiGetAllPromptUses()
{
    $count = DB::table('HS_Prompts')->sum('iUseCount');
    return $count;
}
/******************************************
Get all Prompts
 ******************************************/
function apiGetAllPrompts($type='*',$showdeleted=0,$sortby='sPromptName',$sortdir='asc')
{
        $prompts = DB::table('HS_Prompts')->where('fDeleted','=',$showdeleted)->orderBy($sortby,$sortdir);
        if($type == 'request'){
            $prompts->where('fRequestAvailable','=', 1);
        } else if ($type == 'kb'){
            $prompts->where('fKBAvailable','=', 1);
        }
        return $prompts->get();
}
/******************************************
Run an OpenAI Completion
******************************************/
function run_completion($xPrompt,$inputtext='',$fName='',$lName='') {
    // Validate that the input text is long enough to run through AI.
    // Short input text tends to have poor results and to return the prompt itself
    if (strlen($inputtext) < 20){
        return hs_markdown($inputtext."\n\n".lg('lg_ai_input_too_short'));
    }


    $user = apiGetLoggedInUser();
    $completion = DB::table('HS_Prompts')->where('xPrompt', '=',$xPrompt)->get()->first();
    $open_ai = apiInitialzeOpenAI();

    //unserialize the prompt messages
    $prompts = unserialize($completion->sPrompt);

    $replacements = ['/{{\s*([input.text]+)\s*}}/' => $inputtext,
    '/{{\s*(first.name+)\s*}}/' => $fName,
    '/{{\s*(last.name+)\s*}}/' => $lName,
    '/{{\s*(staff.first.name+)\s*}}/' => $user["sFname"],
    '/{{\s*(staff.last.name+)\s*}}/' => $user["sLname"]];
    //replace vars in messages with their values
    foreach($prompts as $key => $prompt){
        $prompts[$key]['content'] = preg_replace(array_keys($replacements), array_values($replacements), $prompts[$key]['content']);
    }
    $prompts[] = ["role"=>"system","content"=>"You always return results as markdown. Do not mention that you are returning markdown. Do not provide any indication that you have edited the text."];
    $aicall = [
        'model' => hs_setting('cHD_OPENAI_MODEL'),
        'messages' => $prompts,
        'temperature' => 1.0,
        'max_tokens' => 2000,
        'frequency_penalty' => 0,
        'presence_penalty' => 0,
    ];
    $result = $open_ai->chat($aicall);
    $GLOBALS['DB']->Execute('UPDATE HS_Prompts set iUseCount = ? where xPrompt = ?',[$completion->iUseCount+1,$xPrompt]);
    return hs_markdown(json_decode($result)->choices[0]->message->content);
}

function create_prompt($prompt,$name,$kbAvailable,$requestAvailable) {
    $prompt = serialize($prompt);
    DB::table('HS_Prompts')->insert(['sPrompt' => $prompt, 'sPromptName' => $name, 'fKBAvailable' => $kbAvailable,'fRequestAvailable' => $requestAvailable]);
}

function summarize_history($events){
    $open_ai = apiInitialzeOpenAI();
    $request_summaries=[];
    foreach ($events as $event){
        if ($event['xPerson'] > 0) {
            $person = 'Staff';
        } else {
            $person = 'Customer';
        }
        $result = $open_ai->chat([
            'model' => 'gpt-3.5-turbo',
            'messages' => [
                ["role" => "user", "content" => 'Summarize in a couple sentences: '.$person.' said '.$event['tNote'] ]],
            'temperature' => 1.0,
            'max_tokens' => 2000,
            'frequency_penalty' => 0,
            'presence_penalty' => 0,
        ]);
        $request_summaries[] = json_decode($result)->choices[0]->message->content;

    }
    $request_summary_html = '<ul>';
    foreach ($request_summaries as $request_summary){
        $request_summary_html .= '<li>'.$request_summary.'</li>';
    }
    $request_summary_html .= '</ul>';
    if(count($events) > 20) {
        $result = $open_ai->chat([
            'model' => 'gpt-3.5-turbo',
            'messages' => [
                ["role" => "user", "content" => 'Summarize in a paragraph the key points from this conversation: '.$request_summary_html ]],
            'temperature' => 1.0,
            'max_tokens' => 2000,
            'frequency_penalty' => 0,
            'presence_penalty' => 0,
        ]);
        $request_summary_html =json_decode($result)->choices[0]->message->content;
    }
    return $request_summary_html;
}

function translate_history($tNote) {

    $open_ai = apiInitialzeOpenAI();

    $prompts[] = ["role" => "system", "content" => " You are a translator that translates text into ".hs_setting('cHD_OPENAI_LANGUAGE')." Preserve HTML links and images as well as formatting. You output the results as markdown but don't add extra formatting."];
    $prompts[] = ["role"=>"user","content"=>"Translate this text: ".$tNote];
    $aicall = [
        'model' => hs_setting('cHD_OPENAI_MODEL'),
        'messages' => $prompts,
        'temperature' => 1.0,
        'max_tokens' => 2000,
        'frequency_penalty' => 0,
        'presence_penalty' => 0,
    ];
    $result = $open_ai->chat($aicall);
    return hs_markdown(json_decode($result)->choices[0]->message->content);
}
